@@ -3,7 +3,7 @@
 //  \file blaze/math/adaptors/lowermatrix/BaseTemplate.h
 //  \brief Header file for the implementation of the base template of the LowerMatrix
 //
-//  Copyright (C) 2013 Klaus Iglberger - All Rights Reserved
+//  Copyright (C) 2012-2020 Klaus Iglberger - All Rights Reserved
 //
 //  This file is part of the Blaze library. You can redistribute it and/or modify it under
 //  the terms of the New (Revised) BSD License. Redistribution and use in source and binary
@@ -40,8 +40,8 @@
 // Includes
 //*************************************************************************************************
 
-#include <blaze/math/typetraits/IsColumnMajorMatrix.h>
 #include <blaze/math/typetraits/IsDenseMatrix.h>
+#include <blaze/math/typetraits/StorageOrder.h>
 
 
 namespace blaze {
@@ -68,8 +68,12 @@ namespace blaze {
 // parameter:
 
    \code
+   namespace blaze {
+
    template< typename MT, bool SO, bool DF >
    class LowerMatrix;
+
+   } // namespace blaze
    \endcode
 
 //  - MT: specifies the type of the matrix to be adapted. LowerMatrix can be used with any
@@ -177,7 +181,7 @@ namespace blaze {
    using blaze::LowerMatrix;
    using blaze::rowMajor;
 
-   typedef LowerMatrix< CompressedMatrix<double,rowMajor> >  CompressedLower;
+   using CompressedLower = LowerMatrix< CompressedMatrix<double,rowMajor> >;
 
    // Default constructed, row-major 3x3 lower compressed matrix
    CompressedLower A( 3 );
@@ -232,7 +236,7 @@ namespace blaze {
    using blaze::unpadded;
    using blaze::rowMajor;
 
-   typedef LowerMatrix< CustomMatrix<double,unaligned,unpadded,rowMajor> >  CustomLower;
+   using CustomLower = LowerMatrix< CustomMatrix<double,unaligned,unpadded,rowMajor> >;
 
    // Creating a 3x3 lower custom matrix from a properly initialized array
    double array[9] = { 1.0, 0.0, 0.0,
@@ -411,19 +415,23 @@ namespace blaze {
    LowerMatrix< HybridMatrix<float,3UL,3UL,rowMajor> > E;
    LowerMatrix< StaticMatrix<float,3UL,3UL,columnMajor> > F;
 
-   E = A + B;     // Matrix addition and assignment to a row-major lower matrix
-   F = C - D;     // Matrix subtraction and assignment to a column-major lower matrix
-   F = A * D;     // Matrix multiplication between a dense and a sparse matrix
+   E = A + B;     // Matrix addition and assignment to a row-major lower matrix (includes runtime check)
+   F = C - D;     // Matrix subtraction and assignment to a column-major lower matrix (only compile time check)
+   F = A * D;     // Matrix multiplication between a dense and a sparse matrix (includes runtime check)
 
    C *= 2.0;      // In-place scaling of matrix C
-   E  = 2.0 * B;  // Scaling of matrix B
-   F  = C * 2.0;  // Scaling of matrix C
+   E  = 2.0 * B;  // Scaling of matrix B (includes runtime check)
+   F  = C * 2.0;  // Scaling of matrix C (only compile time check)
 
-   E += A - B;    // Addition assignment
-   F -= C + D;    // Subtraction assignment
-   F *= A * D;    // Multiplication assignment
+   E += A - B;    // Addition assignment (includes runtime check)
+   F -= C + D;    // Subtraction assignment (only compile time check)
+   F *= A * D;    // Multiplication assignment (includes runtime check)
    \endcode
 
+// Note that it is possible to assign any kind of matrix to a lower matrix. In case the matrix
+// to be assigned is not lower at compile time, a runtime check is performed.
+//
+//
 // \n \section lowermatrix_block_structured Block-Structured Lower Matrices
 //
 // It is also possible to use block-structured lower matrices:
@@ -441,9 +449,9 @@ namespace blaze {
 // elements in the upper part of the matrix:
 
    \code
-   const StaticMatrix<int,3UL,3UL> B( 1, -4,  5,
-                                      6,  8, -3,
-                                      2, -1,  2 )
+   const StaticMatrix<int,3UL,3UL> B( { { 1, -4,  5 },
+                                        { 6,  8, -3 },
+                                        { 2, -1,  2 } } )
 
    A.insert( 4, 2, B );  // Inserting the elements (4,2)
    A(2,4)(1,1) = -5;     // Invalid manipulation of upper matrix element; Results in an exception
@@ -543,9 +551,9 @@ namespace blaze {
    C = A * B;  // Results in a lower matrix; no runtime overhead
    \endcode
 */
-template< typename MT                               // Type of the adapted matrix
-        , bool SO = IsColumnMajorMatrix<MT>::value  // Storage order of the adapted matrix
-        , bool DF = IsDenseMatrix<MT>::value >      // Density flag
+template< typename MT                      // Type of the adapted matrix
+        , bool SO = StorageOrder_v<MT>     // Storage order of the adapted matrix
+        , bool DF = IsDenseMatrix_v<MT> >  // Density flag
 class LowerMatrix
 {};
 //*************************************************************************************************
